# Program to calculate molecular weight of protein based on its FASTA sequence
#

# Sets initial molecular weight variable (mw) to zero
mw = 0

# Source for residue molecular weights: http://www.matrixscience.com/help/aa_help.html (Accessed 
# on May 8th 2015)
# To calculate the mass of a neutral peptide or protein, sum the residue masses plus the masses 
# of the terminating 
# groups (e.g. H at the N-terminus and OH at the C-terminus).
# Sets dictionary aaMW
aaMW = {"A": 71.0779,"R": 156.1857,"N": 114.1026,"D": 115.0874,
        "C": 103.1429,"E": 129.114,"Q": 128.1292,"G": 57.0513,
        "H": 137.1393,"I": 113.1576,"L": 113.1576,"K": 128.1723,
        "M": 131.1961,"F": 147.1739,"P": 97.1152,"S": 87.0773,
        "T": 101.1039,"W": 186.2099,"Y": 163.1733,"V": 99.1311
        }

# Reads input file name
fastaIn = input("\nGive the input file name => ")
fh = open(fastaIn,'r')  # Opens input file
seqIn = fh.readlines()  # Reads all of the lines in a file and returns them as elements in a list
fh.close()              # Closes input file

# Removes the item at the given position in the list, and return it.
seqIn.pop(0)    # Removes first element of the list (get rid of the first line)

# Transforms list in string, so we will not get error with .replace()
seq=''.join(seqIn)

# Removes all "/n" from the string seq
seq = seq.replace("\n","")

# Looping through to calculate molecular weight
for aa in seq:
    mw += aaMW[aa]

mw = mw + 18.0148 # Sums water molecule

# Counts number of amino acids
count_A = seq.count("A")
count_R = seq.count("R")
count_N = seq.count("N")
count_D = seq.count("D")
count_C = seq.count("C")
count_E = seq.count("E")
count_Q = seq.count("Q")
count_G = seq.count("G")
count_H = seq.count("H")
count_I = seq.count("I")
count_L = seq.count("L")
count_K = seq.count("K")
count_M = seq.count("M")
count_F = seq.count("F")
count_P = seq.count("P")
count_S = seq.count("S")
count_T = seq.count("T")
count_W = seq.count("W")
count_Y = seq.count("Y")
count_V = seq.count("V")

# Shows molecular weight
print("\nThe protein weighs %8.3f"%mw," Daltons")

# Shows percentage if mw > 0
if mw>0:
    print("\nAmino acid\t\t\tPercentage in mass")
    print("Alanine \t\t\t %8.3f"%(100*count_A*aaMW["A"]/mw))       
    print("Arginine\t\t\t %8.3f"%(100*count_R*aaMW["R"]/mw))
    print("Asparagine\t\t\t %8.3f"%(100*count_N*aaMW["N"]/mw))
    print("Aspartate\t\t\t %8.3f"%(100*count_D*aaMW["D"]/mw))
    print("Cysteine\t\t\t %8.3f"%(100*count_C*aaMW["C"]/mw))
    print("Glutamate\t\t\t %8.3f"%(100*count_E*aaMW["E"]/mw))
    print("Glutamine\t\t\t %8.3f"%(100*count_Q*aaMW["Q"]/mw))
    print("Glycine  \t\t\t %8.3f"%(100*count_G*aaMW["G"]/mw))
    print("Histidine\t\t\t %8.3f"%(100*count_H*aaMW["H"]/mw))
    print("Isoleucine\t\t\t %8.3f"%(100*count_I*aaMW["I"]/mw))
    print("Leucine   \t\t\t %8.3f"%(100*count_L*aaMW["L"]/mw))
    print("Lysine    \t\t\t %8.3f"%(100*count_K*aaMW["K"]/mw))
    print("Methionine\t\t\t %8.3f"%(100*count_M*aaMW["M"]/mw))
    print("Phenylalanine\t\t\t %8.3f"%(100*count_F*aaMW["F"]/mw))
    print("Proline    \t\t\t %8.3f"%(100*count_P*aaMW["P"]/mw))
    print("Serine    \t\t\t %8.3f"%(100*count_S*aaMW["S"]/mw))
    print("Threonine\t\t\t %8.3f"%(100*count_T*aaMW["T"]/mw))
    print("Tryptophan\t\t\t %8.3f"%(100*count_W*aaMW["W"]/mw))
    print("Tyrosine\t\t\t %8.3f"%(100*count_Y*aaMW["Y"]/mw))
    print("Valine    \t\t\t %8.3f"%(100*count_V*aaMW["V"]/mw))